aboutsummaryrefslogtreecommitdiff
path: root/odb/oracle/error.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'odb/oracle/error.hxx')
-rw-r--r--odb/oracle/error.hxx12
1 files changed, 8 insertions, 4 deletions
diff --git a/odb/oracle/error.hxx b/odb/oracle/error.hxx
index fdb0537..accfc3f 100644
--- a/odb/oracle/error.hxx
+++ b/odb/oracle/error.hxx
@@ -7,20 +7,24 @@
#include <odb/pre.hxx>
+#include <cstddef> // std::size_t
+
#include <odb/oracle/oracle-fwd.hxx>
-#include <odb/oracle/forward.hxx>
+#include <odb/oracle/forward.hxx> // connection, multiple_exceptions
#include <odb/oracle/version.hxx>
+
#include <odb/oracle/details/export.hxx>
namespace odb
{
namespace oracle
{
// Translate OCI error given an error handle and throw an appropriate
// exception.
//
LIBODB_ORACLE_EXPORT void
- translate_error (OCIError*, sword result);
+ translate_error (OCIError*, sword result, connection* = 0,
+ std::size_t pos = 0, multiple_exceptions* = 0);
LIBODB_ORACLE_EXPORT void
translate_error (connection&, sword result);
@@ -7,20 +7,24 @@
namespace oracle
{
- // Translate OCI error given an error handle and throw an appropriate
- // exception.
+ // Translate OCI error given an error handle and throw (or return,
+ // in case multiple_exceptions is not NULL) an appropriate exception.
//
LIBODB_ORACLE_EXPORT void